# frozen_string_literal: true

require 'hash'

require 'pii_detector/root'
require 'pii_detector/version'
require 'pii_detector/comparator'
require 'pii_detector/configuration'

module PIIDetector
  extend self

  # @param value [Hash]
  # @return [Array]
  def retrieve_pii_keys_from_hash(value)
    value.unique_keys.map { |field| pii_field?(field) ? field : nil }.compact.uniq
  end

  # @param value [String]
  # @return [Boolean]
  def pii_field?(value)
    config.pii_fields.any? { |pii| Comparator.similar?(pii, value) }
  end

  # @return [PIIDetector::Configuration]
  def configure
    @config ||= Configuration.new
    yield(@config) if block_given?
    @config
  end

  # @return [PIIDetector::Configuration]
  def config
    @config || configure
  end
end
